EDA
-------

Main
^^^^^^^^^^^^^^^^

*eda_process()*
"""""""""""""""
.. autofunction:: neurokit2.eda.eda_process

*eda_analyze()*
"""""""""""""""
.. autofunction:: neurokit2.eda.eda_analyze

*eda_plot()*
"""""""""""""
.. autofunction:: neurokit2.eda.eda_plot

*eda_simulate()*
"""""""""""""""""
.. autofunction:: neurokit2.eda.eda_simulate


Preprocessing
^^^^^^^^^^^^^^^^
*eda_clean()*
"""""""""""""
.. autofunction:: neurokit2.eda.eda_clean

*eda_phasic()*
"""""""""""""""""""""
.. autofunction:: neurokit2.eda.eda_phasic

*eda_peaks()*
"""""""""""""""""""""
.. autofunction:: neurokit2.eda.eda_peaks

*eda_fixpeaks()*
"""""""""""""""""""""
.. autofunction:: neurokit2.eda.eda_fixpeaks



Analysis
^^^^^^^^^
*eda_eventrelated()*
"""""""""""""""""""""
.. autofunction:: neurokit2.eda.eda_eventrelated

*eda_intervalrelated()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.eda.eda_intervalrelated

*eda_sympathetic()*
"""""""""""""""""""""
.. autofunction:: neurokit2.eda.eda_sympathetic

*eda_autocor()*
"""""""""""""""
.. autofunction:: neurokit2.eda.eda_autocor

*eda_changepoints()*
"""""""""""""""""""""
.. autofunction:: neurokit2.eda.eda_changepoints



Miscellaneous
^^^^^^^^^^^^^^^^
*eda_findpeaks()*
"""""""""""""""""""""
.. autofunction:: neurokit2.eda.eda_findpeaks




*Any function appearing below this point is not explicitly part of the documentation and should be added. Please open an issue if there is one.*


.. automodule:: neurokit2.eda
   :members:
   :exclude-members: eda_process, eda_analyze, eda_plot, eda_clean, eda_simulate, eda_autocor, eda_phasic, eda_changepoints, eda_peaks, eda_fixpeaks, eda_sympathetic, eda_eventrelated, eda_intervalrelated, eda_findpeaks